package com.example.catchTheLetters.service;

import com.example.catchTheLetters.entity.PlayerInput;
import org.springframework.web.socket.WebSocketSession;

/**
 * 房间服务
 *
 * @author spyn
 */
public interface RoomService {
    /**
     * 添加玩家
     * @param roomId 房间号
     * @param session WebSocket 会话
     * @param token 玩家 token
     */
    void addPlayer(long roomId, WebSocketSession session, String token);

    /**
     * 移除玩家
     * @param roomId 房间号
     * @param session WebSocket 会话
     */
    void removePlayer(long roomId, WebSocketSession session);

    /**
     * 开始游戏
     * @param roomId 房间号
     * @param session WebSocket 会话
     */
    void startGame(long roomId, WebSocketSession session);

    /**
     * 取消开始游戏
     * @param roomId 房间号
     * @param session WebSocket 会话
     */
    void cancelStartGame(long roomId, WebSocketSession session);

    /**
     * 结束游戏
     * @param roomId 房间号
     */
    void endGame(long roomId);

    /**
     * 处理玩家输入
     * @param roomId 房间号
     * @param session WebSocket 会话
     * @param input 玩家输入
     */
    void handleInput(long roomId, WebSocketSession session, PlayerInput input);

    /**
     * 创建房间
     * @param session WebSocket 会话
     * @param token 玩家 token
     */
    void createRoom(WebSocketSession session, String token);

    /**
     * 移除房间
     * @param roomId 房间号
     */
    void removeRoom(long roomId);
}
